@@ -7,9 +7,11 @@ from drf_spectacular.generators import SchemaGenerator
 from drf_spectacular.types import OpenApiTypes
 from drf_spectacular.utils import (
     OpenApiCallback,
+    OpenApiExample,
     OpenApiResponse,
     PolymorphicProxySerializer,
     extend_schema,
+    extend_schema_serializer,
     inline_serializer,
 )
 from rest_framework import serializers
@@ -214,12 +216,17 @@ def test_error_codes_for_polymorphic_serializer():
     create_error_codes = schema["components"]["schemas"][
         "ValidateCreateNonFieldErrorsErrorComponent"
     ]["properties"]["code"]["enum"]
-    assert set(create_error_codes) == {"invalid", "object1_code", "object2_code"}
+    assert set(create_error_codes) == {
+        "invalid",
+        "null",
+        "object1_code",
+        "object2_code",
+    }
 
     patch_error_codes = schema["components"]["schemas"][
         "ValidatePartialUpdateNonFieldErrorsErrorComponent"
     ]["properties"]["code"]["enum"]
-    assert set(patch_error_codes) == {"invalid", "object1_code", "object2_code"}
+    assert set(patch_error_codes) == {"invalid", "null", "object1_code", "object2_code"}
 
 
 class CustomFilterSet(FilterSet):
@@ -621,3 +628,115 @@ def test_get_view_does_not_raise_missing_serializer_warning(capsys):
 def test_schema_generated(api_client):
     response = api_client.get("/schema/")
     assert response.status_code == 200
+
+
+def test_protected_schema_response(api_client):
+    response = api_client.get("/protected-schema/")
+    assert response.status_code == 403
+
+
+@extend_schema_serializer(
+    examples=[
+        OpenApiExample(
+            "extend_schema_serializer_example",
+            summary="short summary",
+            value={"field": "specific_value"},
+            response_only=True,
+        ),
+    ]
+)
+class SomeSerializer(serializers.Serializer):
+    field = serializers.CharField()
+
+
+class ExtendSchemaSerializerView(GenericAPIView):
+    serializer_class = SomeSerializer
+
+    def get(self, request, *args, **kwargs):
+        serializer = self.get_serializer(instance={"field": "value1"})
+        return Response(serializer.data)
+
+
+def test_examples_from_extend_schema_serializer_are_showing_up(api_client):
+    view = ExtendSchemaSerializerView.as_view()
+    schema = generate_view_schema("extend_schema_serializer/", view)
+    resp200 = schema["paths"]["/extend_schema_serializer/"]["get"]["responses"]["200"]
+    assert "examples" in resp200["content"]["application/json"]
+    examples = resp200["content"]["application/json"]["examples"]
+    assert (
+        examples["ExtendSchemaSerializerExample"]["value"]["field"] == "specific_value"
+    )
+
+
+class CustomError403Serializer(serializers.Serializer):
+    code = serializers.ChoiceField(choices=[("perm_denied", "perm_denied")])
+    detail = serializers.CharField()
+    attr = serializers.CharField(allow_null=True)
+
+
+class CustomErrorResponse403Serializer(serializers.Serializer):
+    type = serializers.ChoiceField(choices=ClientErrorEnum.choices)
+    errors = CustomError403Serializer(many=True)
+
+
+class ExpSerializer(serializers.Serializer):
+    field = serializers.CharField()
+
+
+class ExamplesView(GenericAPIView):
+    authentication_classes = [BasicAuthentication]
+    permission_classes = [IsAuthenticated, IsAdminUser]
+    serializer_class = ExpSerializer
+
+    @extend_schema(
+        responses={
+            403: OpenApiResponse(
+                response=CustomErrorResponse403Serializer,
+                description="Registration is disabled",
+            )
+        },
+        examples=[
+            OpenApiExample(
+                "Example",
+                summary="short summary",
+                description="longer description",
+                value={
+                    "type": "client_error",
+                    "errors": [
+                        {
+                            "code": "perm_denied",
+                            "detail": "Registration is disabled.",
+                            "attr": None,
+                        }
+                    ],
+                },
+                status_codes=[403],
+            ),
+        ],
+    )
+    def get(self, request, *args, **kwargs):
+        serializer = self.get_serializer(instance={"field": "value1"})
+        return Response(serializer.data)
+
+
+def test_default_examples_are_showing_up_only_when_status_code_is_allowed(
+    api_client, settings
+):
+    settings.DRF_STANDARDIZED_ERRORS = {"ALLOWED_ERROR_STATUS_CODES": ["403"]}
+
+    route = "perm-denied/"
+    view = ExamplesView.as_view()
+    schema = generate_view_schema(route, view)
+    responses = get_responses(schema, route)
+    examples = responses["403"]["content"]["application/json"]["examples"]
+    assert "Example" in examples
+    assert "PermissionDenied" in examples
+
+    settings.DRF_STANDARDIZED_ERRORS = {"ALLOWED_ERROR_STATUS_CODES": []}
+    route = "perm-denied/"
+    view = ExamplesView.as_view()
+    schema = generate_view_schema(route, view)
+    responses = get_responses(schema, route)
+    examples = responses["403"]["content"]["application/json"]["examples"]
+    assert "Example" in examples
+    assert "PermissionDenied" not in examples
